@@ -29,9 +29,8 @@ def retry_rest_api(n: int = None, wait: int = 3):
                     last_error = e
                     if e.response and e.response.status_code not in RETRY_HTTP_CODES:
                         k = 0
-                    else:
-                        k -= 1
-                if k > 0 and wait > 0:
+                k -= 1
+                if k >= 0 and wait > 0:
                     time.sleep(wait)
             if last_error is not None:
                 raise last_error
