@@ -95,8 +95,11 @@ class BaseWorker:
             res = self._source_method(data)
             if res:
                 if self._sink:
-                    self._producer.send(res)
-                    self._sink_method(data)
+                    if not isinstance(res, list):
+                        res = [res]
+                    for r in res:
+                        self._producer.send(r)
+                        self._sink_method(r)
         except Exception as e:
             log.error(f'Error occurred: {e}', exc_info=True)
 
